Date: 01 4, 2002 12:00:46 PM

# prxtree

## Purpose

OBSOLETE. To fileName, print the first node called name found in the ordth element's tree, preceded by prestr and followed by poststr. If named node is not found, nothing is printed out.

## Syntax

prxtree(fileName, prestr, ord, name, poststr)

fileName - type: str
prestr - type: str
ord - type:
name - type: str
poststr - type: str

## Returns

## Remarks

The output file (fileName) must be set up in advance using openfile, fileout or an output statement.

## Example

The code prxtree("out.txt", "date: ", 3, "_date", "\n") prints out a line like "date: 3/9/99 <cr>" if a _date node is found within the subtree of element 3.

## See Also

prchild, prtree, openfile, fileout, POST Actions